Skip to contents

Metadata provided as a list of tibbles will be validated for consistency against the loaded analysis data of the provided MRMhubExperiment object and then transferred.

Usage

add_metadata(data = NULL, metadata, excl_unmatched_analyses = FALSE)

Arguments

data

MRMhubExperiment object

metadata

List of tibbles or data.frames containing analysis, feature, istd, response curve tables

excl_unmatched_analyses

Exclude analyses (samples) that have no matching metadata

Value

An updated MRMhubExperiment object

See also