Returns the start time of the analysis, corresponding to the earliest acquisition_time_stamp from the dataset.
Arguments
- data
A
MRMhubExperimentobject
Returns the start time of the analysis, corresponding to the earliest acquisition_time_stamp from the dataset.
A MRMhubExperiment object