Returns the number of analyses in the dataset, with an optional
filter based on qc_types.
Arguments
- data
A
MRMhubExperimentobject- qc_types
Defines the
qc_typesto be counted. IfNULLorNA, all analyses will be counted.
Returns the number of analyses in the dataset, with an optional
filter based on qc_types.
A MRMhubExperiment object
Defines the qc_types to be counted. If NULL or NA,
all analyses will be counted.