Skip to contents

Returns the lower and upper analysis number (sequence position) spanned by the specified batch or range of batches.

Usage

get_batch_boundaries(data = NULL, batch_indices = NULL)

Arguments

data

MRMhubExperiment object

batch_indices

A numeric vector with one or two elements, representing the first and/or last batch index (i.e., sequential batch number). If NULL or invalid, the function will abort.

Value

A vector with two elements: the lower and upper analysis number for the specified batch(es).