Calculates the median run time (in seconds) based of the timestamps differences between consecutive analyses in the sequence.
Arguments
- data
A
MRMhubExperimentobject
Calculates the median run time (in seconds) based of the timestamps differences between consecutive analyses in the sequence.
A MRMhubExperiment object