Retrieve metadata from imported analysis data
Source:R/metadata-import.R
import_metadata_from_data.RdRetrieves available metadata from the imported analysis data and
associates it with the provided MRMhubExperiment object.
Arguments
- data
A
MRMhubExperimentobject- qc_type_column_name
Column name in the imported raw data representing the
qc_type
Value
An updated MRMhubExperiment object