The labels a feature's mrm_pattern may take, optionally for one
product-ion origin. Single source of truth shared by metadata validation and
the Excel template dropdown (so they cannot drift).
The labels a feature's mrm_pattern may take, optionally for one
product-ion origin. Single source of truth shared by metadata validation and
the Excel template dropdown (so they cannot drift).