Normalize feature intensities using internal standards
Source:R/calc-istd-normalization.R
normalize_by_istd.RdNormalize feature intensities by dividing them by the intensities
of the corresponding internal standards (ISTDs). Each feature
must have a defined internal standard (ISTD) in the feature metadata.
Arguments
- data
A
MRMhubExperimentobject.- ignore_missing_annotation
If
FALSE, the function will raise an error when an ISTD is not defined for one or more features (excluding the ISTDs themselves). IfTRUE, features with missing ISTD annotations will have NA values in the normalized intensities.
Value
A MRMhubExperiment object with normalized feature intensities