Generates a data processing report from a MRMhubExperiment object and writes it to an Excel file.
The report includes information on the data processing steps, quality control metrics, feature concentrations, and metadata.
Following tables will be created as sheets in the EXCEL file, in this order:
Usage
save_report_xlsx(
data = NULL,
path,
filtered_variable = "conc",
normalized_variable = NA,
overwrite = TRUE,
create_dir = TRUE
)Arguments
- data
A
MRMhubExperimentobject containing original and processed data and metadata.- path
A character string specifying the file name and path for the Excel file. If the path does not include an
.xlsxextension, it is added automatically.- filtered_variable
A character string specifying the variable name in the filtered data to be exported. It must be one of "conc", "intensity", "norm_intensity", "response", "area", "height", "conc_raw", "rt", or "fwhm". The defined variable name will be included in the sheet name. Default is "conc".
- normalized_variable
A character string indicating if and which normalized feature values (by reference sample) to include in the report.See also
[calibrate_by_reference()].- overwrite
A logical value indicating whether to overwrite the file if it already exists. Default is
TRUE.- create_dir
A logical value. If
TRUE(the default), the parent directory ofpathis created if it does not yet exist.
Details
Info: Report date, author, MRMhub version and the concentration unit.
Feature_QC_metrics: Quality control metrics of all features. An infinite signal-to-blank ratio (feature not detected in the blank) is written as the text
Inf.Calibration_metrics: External calibration results per feature.
QCfilt_x_StudySamples: Feature (QC)-filtered data (variable defined via
filtered_variable) in study samples ('SPL'). Filter have to be set viafilter_features_qc(). The x corresponds to thefiltered_variableargument.QCfilt_x_AllSamples: Feature (QC)-filtered data (variable defined via
filtered_variable) in all samples. Filter have to be set viafilter_features_qc(). The x corresponds to thefiltered_variableargument.Raw_Intensity_FullDataset: Raw feature intensities from the full, non-filtered dataset.
Norm_Intensity_FullDataset: Normalized feature intensities from the full, non-filtered dataset.
Conc_FullDataset: Final feature concentrations from the full, non-filtered dataset.
x_NormalizedByRef_Full: Study-sample values normalized by a reference sample (see
calibrate_by_reference()), if available.SampleMetadata: Analysis metadata that was imported and used for processing steps
FeatureMetadata: Feature metadata that was imported and used for processing steps
InternalStandards: Internal standards metadata with concentrations
BatchInfo: Information on batches and positions of first and last analysis/sample in each batch
Interferences: Derived and declared interference relationships (interfering feature, contribution factor, overlap type, source) with the per-feature correction impact when the correction has been applied.
Internal standards are not included in the concentration and QC-filtered
sheets. For reference-normalized variables, sheet names use short labels
to stay within Excel's 31 characters, with "Ref" marking values normalized
by a reference sample (e.g. QCfilt_ConcRef_StudySamples).
If certain data sets are not available, the function includes empty tables for the corresponding dataset.
Concentration corresponds to the final concentration values after applying isotope correction, and drift and batch correction, if applicable. If any corrections, such as drift or batch correction, were applied to raw or normalized intensities, the exported values will reflect these corrections.