The MRMhubExperiment object is the core data structure utilized within the MRMhub workflow, encapsulating all relevant experimental data and metadata.
It also includes processing results, details of the applied processing steps, and the current status of the data.
Slots
titleTitle of the experiment
analysis_typeAnalysis type, one of "lipidomics", "metabolomics", "externalcalib", "others"
feature_intensity_varFeature variable used as default for calculations
conc_analyte_unitUnit of the analyte amount underlying
feature_conc, set when the data are quantitated."pmol"or"ng"for ISTD quantitation (seequantify_by_istd()), or the calibrant concentration unit (e.g."nmol/L") for calibration quantitation. Divided bysample_amount_unitbyget_conc_unit()to name the unit offeature_conc.NAwhen not quantitated.dataset_origOriginal imported analysis data. Required fields:
datasetProcessed analysis data. Required fields:
dataset_filteredProcessed analysis data. Required fields:
annot_analysesAnnotation of analyses/runs
annot_featuresAnnotation of measured features.
annot_istdsAnnotation of Internal Standard concs.
annot_responsecurvesAnnotation of response curves (RQC). Required fields
annot_qcconcentrationsAnnotation of calibration curves. Required fields
annot_studysamplesAnnotation of study samples. Required fields:
annot_batchesAnnotation of batches. Required fields:
metrics_qcQC information for each measured feature
metrics_calibrationCalibration metrics calculated from external calibration curves for each measured feature
status_processingStatus within the data processing workflow
is_istd_normalizedFlag if data has been ISTD normalized
is_quantitatedFlag if data has been quantitated using ISTD and sample amount
is_filteredFlag if data has been filtered based on QC parameters
is_isotope_corrFlag if one or more features have been isotope corrected
has_outliers_techFlag if data has technical analysis/sample outliers
analyses_excludedAnalyses excluded from processing, plots and reporting, unless explicitly requested
features_excludedFeatures excluded from processing, plots and reporting, unless explicitly requested
var_drift_correctedList indicating which variables are drift corrected
var_batch_correctedList indicating which variables are batch corrected