Metadata provided as a list of tibbles will be validated for consistency against the loaded analysis data of the provided MRMhubExperiment object and then transferred.
Arguments
- data
MRMhubExperimentobject- metadata
List of tibbles or data.frames containing analysis, feature, istd, response curve tables
- excl_unmatched_analyses
Exclude analyses (samples) that have no matching metadata
Value
An updated MRMhubExperiment object
See also
The metadata guide.