Returns the end time of the analysis, corresponding to the last acquisition_time_stamp from the dataset.
Note: if estimate_sequence_end is set to FALSE, the function will return
the timestamp of the last analysis in the dataset, corresponding to the start of
the last analysis. Set estimate_sequence_end to TRUE to estimate the end
time of the analysis sequence, based on the median runtime.
Arguments
- data
A
MRMhubExperimentobject- estimate_sequence_end
If
TRUE, the function will estimate the end time of the analysis sequence based on the median runtime.FALSEwill return the start time of the last analysis in the sequence.