Get the annotated or the originally imported analytical data
Source:R/data-managment.R
get_analyticaldata.RdGet the annotated or the originally imported analytical data
Arguments
- data
MRMhubExperimentobject- annotated
Boolean indicating whether to return the annotated data (
FALSE) or the original imported data (TRUE)