Get the start and end analysis numbers of specified batches
Source:R/data-managment.R
get_batch_boundaries.RdReturns the lower and upper analysis number (sequence position) spanned by the specified batch or range of batches.
Arguments
- data
MRMhubExperimentobject- batch_indices
A numeric vector with one or two elements, representing the first and/or last batch index (i.e., sequential batch number). If NULL or invalid, the function will abort.