Plot QC filtering summary by feature class
Source:R/plots-qc-filtering.R
plot_qc_summary_byclass.RdThis function provides a summary of feature QC filtering based on feature class,
showing the number of features that passed or failed various quality control criteria.
It visualizes the filtering in a hierarchical sequence. Features are first evaluated
against lower-level filters such as signal-to-blank (S/B) ratios and limit of detection (LOD),
followed by higher-level filters like the coefficient of variation (CV) or linear regression results.
This means that a feature is classified as failing a given criterion (e.g., CV)
only if it has passed all hierarchically lower filters (e.g., S/B ratio and LOD).
See also
plot_qc_summary_overall() for an overall summary plot
filter_features_qc() for comparing QC metrics
Other QC plots:
plot_feature_correlations(),
plot_normalization_qc(),
plot_pca(),
plot_pca_loading(),
plot_qc_interferences(),
plot_qc_matrixeffects(),
plot_qc_summary_overall(),
plot_qcmetrics_comparison(),
plot_rla_boxplot(),
plot_rt_vs_chain(),
plot_runscatter(),
plot_runsequence()